package jdk.javadoc.internal.tool.resources;

public final class javadoc_ja extends java.util.ListResourceBundle {
    protected final Object[][] getContents() {
        return new Object[][] {
            { "doclet.internal.report.bug", "Bug Database (https://bugs.java.com)\u3067\u91CD\u8907\u304C\u306A\u3044\u304B\u3092\u3054\u78BA\u8A8D\u306E\u3046\u3048\u3001Java bug\u30EC\u30DD\u30FC\u30C8\u30FB\u30DA\u30FC\u30B8\n(https://bugreport.java.com)\u3067javadoc\u30C4\u30FC\u30EB\u306B\u5BFE\u3059\u308Bbug\u306E\u767B\u9332\u3092\u304A\u9858\u3044\u3044\u305F\u3057\u307E\u3059\u3002\n\u30EC\u30DD\u30FC\u30C8\u306B\u306F\u3001\u30A8\u30E9\u30FC\u30FB\u30E1\u30C3\u30BB\u30FC\u30B8\u3068\u6B21\u306E\u8A3A\u65AD\u5185\u5BB9\u3092\u542B\u3081\u3066\u304F\u3060\u3055\u3044\u3002\u3054\u5354\u529B\u3042\u308A\u304C\u3068\u3046\u3054\u3056\u3044\u307E\u3059\u3002" },
            { "javadoc.class_not_found", "\u30AF\u30E9\u30B9{0}\u304C\u898B\u3064\u304B\u308A\u307E\u305B\u3093\u3002" },
            { "javadoc.error", "\u30A8\u30E9\u30FC" },
            { "javadoc.error.msg", "{0}: \u30A8\u30E9\u30FC - {1}" },
            { "javadoc.fullversion", "{0}\u30D5\u30EB\u30FB\u30D0\u30FC\u30B8\u30E7\u30F3\"{1}\"" },
            { "javadoc.note.msg", "{1}" },
            { "javadoc.note.pos.msg", "{0}: {1}" },
            { "javadoc.version", "{0} {1}" },
            { "javadoc.warning", "\u8B66\u544A" },
            { "javadoc.warning.msg", "{0}: \u8B66\u544A - {1}" },
            { "main.Building_tree", "Javadoc\u60C5\u5831\u3092\u69CB\u7BC9\u3057\u3066\u3044\u307E\u3059..." },
            { "main.Loading_source_file", "\u30BD\u30FC\u30B9\u30FB\u30D5\u30A1\u30A4\u30EB{0}\u3092\u8AAD\u307F\u8FBC\u3093\u3067\u3044\u307E\u3059..." },
            { "main.Loading_source_files_for_package", "\u30D1\u30C3\u30B1\u30FC\u30B8{0}\u306E\u30BD\u30FC\u30B9\u30FB\u30D5\u30A1\u30A4\u30EB\u3092\u8AAD\u307F\u8FBC\u3093\u3067\u3044\u307E\u3059..." },
            { "main.No_modules_packages_or_classes_specified", "\u30E2\u30B8\u30E5\u30FC\u30EB\u3001\u30D1\u30C3\u30B1\u30FC\u30B8\u307E\u305F\u306F\u30AF\u30E9\u30B9\u304C\u6307\u5B9A\u3055\u308C\u3066\u3044\u307E\u305B\u3093\u3002" },
            { "main.Xusage", "" },
            { "main.Xusage.foot", "\n\u3053\u308C\u3089\u306F\u975E\u6A19\u6E96\u30AA\u30D7\u30B7\u30E7\u30F3\u3067\u3042\u308A\u4E88\u544A\u306A\u3057\u306B\u5909\u66F4\u3055\u308C\u308B\u3053\u3068\u304C\u3042\u308A\u307E\u3059\u3002" },
            { "main.assertion.error", "\u30A2\u30B5\u30FC\u30B7\u30E7\u30F3\u304C\u5931\u6557\u3057\u307E\u3057\u305F: \"{0}}\"" },
            { "main.cannot_use_sourcepath_for_modules", "\u30BD\u30FC\u30B9\u30FB\u30D1\u30B9\u306F\u8907\u6570\u306E\u30E2\u30B8\u30E5\u30FC\u30EB{0}\u306B\u4F7F\u7528\u3067\u304D\u307E\u305B\u3093" },
            { "main.cant.read", "{0}\u3092\u8AAD\u307F\u8FBC\u3081\u307E\u305B\u3093" },
            { "main.could_not_instantiate_class", "\u30AF\u30E9\u30B9{0}\u3092\u30A4\u30F3\u30B9\u30BF\u30F3\u30B9\u5316\u3067\u304D\u307E\u305B\u3093\u3067\u3057\u305F" },
            { "main.doclet.usage.header", "\n{0} doclet\u306B\u3088\u308A\u63D0\u4F9B\u3055\u308C\u308B\u3082\u306E:" },
            { "main.doclet_class_not_found", "doclet\u30AF\u30E9\u30B9{0}\u304C\u898B\u3064\u304B\u308A\u307E\u305B\u3093" },
            { "main.doclet_could_not_get_location", "{0}\u306E\u5834\u6240\u3092\u53D6\u5F97\u3067\u304D\u307E\u305B\u3093\u3067\u3057\u305F" },
            { "main.doclet_could_not_set_location", "{0}\u306E\u5834\u6240\u3092\u8A2D\u5B9A\u3067\u304D\u307E\u305B\u3093\u3067\u3057\u305F" },
            { "main.doclet_no_classloader_found", "{0}\u3092\u30ED\u30FC\u30C9\u3059\u308B\u30AF\u30E9\u30B9\u30ED\u30FC\u30C0\u30FC\u3092\u53D6\u5F97\u3067\u304D\u307E\u305B\u3093\u3067\u3057\u305F" },
            { "main.done_in", "[{0}\u30DF\u30EA\u79D2\u3067\u5B8C\u4E86]" },
            { "main.error", "\u30A8\u30E9\u30FC{0}\u500B" },
            { "main.errors", "\u30A8\u30E9\u30FC{0}\u500B" },
            { "main.fatal.error", "\u81F4\u547D\u7684\u30A8\u30E9\u30FC\u304C\u767A\u751F\u3057\u307E\u3057\u305F: {0}" },
            { "main.file.manager.list", "\u30D5\u30A1\u30A4\u30EB\u306E\u30EA\u30B9\u30C8\u4E2D\u306EFileManager\u30A8\u30E9\u30FC: \"{0}\"" },
            { "main.file_not_found", "\u30D5\u30A1\u30A4\u30EB\"{0}\"\u304C\u898B\u3064\u304B\u308A\u307E\u305B\u3093" },
            { "main.illegal_class_name", "\u30AF\u30E9\u30B9\u540D\u304C\u4E0D\u6B63\u3067\u3059: \"{0}\"" },
            { "main.illegal_option_value", "\u4E0D\u6B63\u306A\u30AA\u30D7\u30B7\u30E7\u30F3\u5024: \"{0}\"" },
            { "main.illegal_package_name", "\u30D1\u30C3\u30B1\u30FC\u30B8\u540D\"{0}\"\u306F\u4E0D\u6B63\u3067\u3059" },
            { "main.internal.error", "\u5185\u90E8\u30A8\u30E9\u30FC\u304C\u767A\u751F\u3057\u307E\u3057\u305F" },
            { "main.invalid_flag", "{0}\u306F\u7121\u52B9\u306A\u30D5\u30E9\u30B0\u3067\u3059" },
            { "main.legacy_api", "\u30D1\u30C3\u30B1\u30FC\u30B8com.sun.javadoc\u3001com.sun.tools.doclets\u304A\u3088\u3073\n\u305D\u308C\u3089\u306E\u5B9F\u88C5\u5185\u306E\u53E4\u3044Doclet\u304A\u3088\u3073Taglet API\u306F\u3001\n\u4ECA\u5F8C\u306EJDK\u30EA\u30EA\u30FC\u30B9\u3067\u524A\u9664\u3055\u308C\u308B\u4E88\u5B9A\u3067\u3059\u3002\u3053\u308C\u3089\u306E\n\u30B3\u30F3\u30DD\u30FC\u30CD\u30F3\u30C8\u306Fjdk.javadoc.doclet\u306E\u65B0\u3057\u3044API\u306B\u3088\u3063\u3066\u7F6E\u304D\u63DB\u3048\u3089\u308C\u307E\u3057\u305F\u3002\n\u30E6\u30FC\u30B6\u30FC\u306B\u306F\u65B0\u3057\u3044API\u306B\u79FB\u884C\u3059\u308B\u3053\u3068\u3092\u5F37\u304F\u304A\u85A6\u3081\u3057\u307E\u3059\u3002\n" },
            { "main.malformed_locale_name", "\u30ED\u30B1\u30FC\u30EB\u540D{0}\u306E\u66F8\u5F0F\u304C\u6B63\u3057\u304F\u3042\u308A\u307E\u305B\u3093" },
            { "main.module_not_found", "\u30E2\u30B8\u30E5\u30FC\u30EB{0}\u304C\u898B\u3064\u304B\u308A\u307E\u305B\u3093\n" },
            { "main.module_not_found_on_sourcepath", "\u30BD\u30FC\u30B9\u30FB\u30D1\u30B9\u306B\u30E2\u30B8\u30E5\u30FC\u30EB{0}\u304C\u898B\u3064\u304B\u308A\u307E\u305B\u3093" },
            { "main.more_than_one_doclet_specified_0_and_1", "\u8907\u6570\u306Edoclet({0}\u3068{1})\u304C\u6307\u5B9A\u3055\u308C\u3066\u3044\u307E\u3059\u3002" },
            { "main.no_source_files_for_package", "\u30D1\u30C3\u30B1\u30FC\u30B8{0}\u306E\u30BD\u30FC\u30B9\u30FB\u30D5\u30A1\u30A4\u30EB\u304C\u3042\u308A\u307E\u305B\u3093" },
            { "main.only_one_argument_with_equals", "\u8907\u6570\u306E\u5F15\u6570\u3092\u5FC5\u8981\u3068\u3059\u308B\u30AA\u30D7\u30B7\u30E7\u30F3\u306B''=''\u69CB\u6587\u3092\u4F7F\u7528\u3059\u308B\u3053\u3068\u306F\u3067\u304D\u307E\u305B\u3093" },
            { "main.opt.J.arg", "<flag>" },
            { "main.opt.J.desc", "<flag>\u3092\u5B9F\u884C\u30B7\u30B9\u30C6\u30E0\u306B\u76F4\u63A5\u6E21\u3059" },
            { "main.opt.Xmaxerrs.arg", "<number>" },
            { "main.opt.Xmaxerrs.desc", "\u51FA\u529B\u3059\u308B\u30A8\u30E9\u30FC\u306E\u6700\u5927\u6570\u3092\u8A2D\u5B9A\u3059\u308B" },
            { "main.opt.Xmaxwarns.arg", "<number>" },
            { "main.opt.Xmaxwarns.desc", "\u51FA\u529B\u3059\u308B\u8B66\u544A\u306E\u6700\u5927\u6570\u3092\u8A2D\u5B9A\u3059\u308B" },
            { "main.opt.Xold.desc", "\u65E7\u5F0F\u306Ejavadoc\u30C4\u30FC\u30EB\u3092\u8D77\u52D5\u3059\u308B" },
            { "main.opt.add.exports.arg", "<module>/<package>=<other-module>(,<other-module>)*" },
            { "main.opt.add.exports.desc", "\u305D\u306E\u5B9A\u7FA9\u30E2\u30B8\u30E5\u30FC\u30EB\u304B\u3089\u3001\u8FFD\u52A0\u306E\u30E2\u30B8\u30E5\u30FC\u30EB\u3001\u307E\u305F\u306F<other-module>\u304C\nALL-UNNAMED\u3067\u3042\u308B\u5834\u5408\u306F\u3059\u3079\u3066\u306E\u540D\u524D\u306E\u306A\u3044\u30E2\u30B8\u30E5\u30FC\u30EB\u306B\n\u30A8\u30AF\u30B9\u30DD\u30FC\u30C8\u6E08\u3068\u307F\u306A\u3055\u308C\u308B\u3088\u3046\u306B\u30D1\u30C3\u30B1\u30FC\u30B8\u3092\u6307\u5B9A\u3057\u307E\u3059" },
            { "main.opt.add.modules.arg", "<module>(,<module>)*" },
            { "main.opt.add.modules.desc", "\u521D\u671F\u30E2\u30B8\u30E5\u30FC\u30EB\u306B\u52A0\u3048\u3066\u89E3\u6C7A\u3059\u308B\u30EB\u30FC\u30C8\u30FB\u30E2\u30B8\u30E5\u30FC\u30EB\u3001\u307E\u305F\u306F\n<module>\u304CALL-MODULE-PATH\u3067\u3042\u308B\u5834\u5408\u306F\u30E2\u30B8\u30E5\u30FC\u30EB\u30FB\u30D1\u30B9\u306E\n\u3059\u3079\u3066\u306E\u30E2\u30B8\u30E5\u30FC\u30EB\u3002" },
            { "main.opt.add.reads.arg", "<module>=<other-module>(,<other-module>)*" },
            { "main.opt.add.reads.desc", "\u6307\u5B9A\u306E\u30E2\u30B8\u30E5\u30FC\u30EB\u3067\u5FC5\u9808\u3068\u307F\u306A\u3055\u308C\u308B\u3088\u3046\u306B\u8FFD\u52A0\u30E2\u30B8\u30E5\u30FC\u30EB\u3092\u6307\u5B9A\u3057\u307E\u3059\u3002\n\u540D\u524D\u306E\u306A\u3044\u30E2\u30B8\u30E5\u30FC\u30EB\u3092\u5FC5\u8981\u3068\u3059\u308B\u5834\u5408\u3001<other-module>\u306FALL-UNNAMED\n\u306B\u3057\u307E\u3059\u3002" },
            { "main.opt.bootclasspath.arg", "<path>" },
            { "main.opt.bootclasspath.desc", "\u975E\u30E2\u30B8\u30E5\u30E9\u30FB\u30EA\u30EA\u30FC\u30B9\u3067\u4F7F\u7528\u3055\u308C\u308B\u30D7\u30E9\u30C3\u30C8\u30D5\u30A9\u30FC\u30E0\u30FB\u30AF\u30E9\u30B9\u30FB\u30D5\u30A1\u30A4\u30EB\n\u306E\u5834\u6240\u3092\u30AA\u30FC\u30D0\u30FC\u30E9\u30A4\u30C9\u3059\u308B" },
            { "main.opt.breakiterator.desc", "BreakIterator\u3067\u6700\u521D\u306E\u6587\u3092\u8A08\u7B97\u3059\u308B" },
            { "main.opt.class.path.arg", "<path>" },
            { "main.opt.class.path.desc", "\u30E6\u30FC\u30B6\u30FC\u30FB\u30AF\u30E9\u30B9\u30FB\u30D5\u30A1\u30A4\u30EB\u306E\u3042\u308B\u5834\u6240\u3092\u6307\u5B9A\u3059\u308B" },
            { "main.opt.doclet.arg", "<class>" },
            { "main.opt.doclet.desc", "\u4EE3\u66FFdoclet\u3092\u4ECB\u3057\u3066\u51FA\u529B\u3092\u751F\u6210\u3059\u308B" },
            { "main.opt.docletpath.arg", "<path>" },
            { "main.opt.docletpath.desc", "doclet\u30AF\u30E9\u30B9\u30FB\u30D5\u30A1\u30A4\u30EB\u306E\u3042\u308B\u5834\u6240\u3092\u6307\u5B9A\u3059\u308B" },
            { "main.opt.enable.preview.desc", "\u30D7\u30EC\u30D3\u30E5\u30FC\u8A00\u8A9E\u6A5F\u80FD\u3092\u6709\u52B9\u306B\u3059\u308B\u3002-source\u307E\u305F\u306F--release\u3068\u3068\u3082\u306B\n\u4F7F\u7528\u3055\u308C\u307E\u3059\u3002" },
            { "main.opt.encoding.arg", "<name>" },
            { "main.opt.encoding.desc", "\u30BD\u30FC\u30B9\u30FB\u30D5\u30A1\u30A4\u30EB\u306E\u30A8\u30F3\u30B3\u30FC\u30C7\u30A3\u30F3\u30B0\u540D" },
            { "main.opt.exclude.arg", "<pkglist>" },
            { "main.opt.exclude.desc", "\u9664\u5916\u3059\u308B\u30D1\u30C3\u30B1\u30FC\u30B8\u30FB\u30EA\u30B9\u30C8\u3092\u6307\u5B9A\u3059\u308B" },
            { "main.opt.expand.requires.arg", "<value>" },
            { "main.opt.expand.requires.desc", "\u30C9\u30AD\u30E5\u30E1\u30F3\u30C8\u5316\u3059\u308B\u30E2\u30B8\u30E5\u30FC\u30EB\u306E\u30BB\u30C3\u30C8\u3092\u62E1\u5F35\u3059\u308B\u305F\u3081\u306E\n\u30C4\u30FC\u30EB\u3092\u6307\u5B9A\u3059\u308B\u3002\u30C7\u30D5\u30A9\u30EB\u30C8\u3067\u306F\u3001\u30B3\u30DE\u30F3\u30C9\u30E9\u30A4\u30F3\u3067\u660E\u793A\u7684\u306B\n\u6307\u5B9A\u3055\u308C\u305F\u30E2\u30B8\u30E5\u30FC\u30EB\u306E\u307F\u304C\u30C9\u30AD\u30E5\u30E1\u30F3\u30C8\u5316\u3055\u308C\u307E\u3059\u3002\"transitive\"\u306E\u5024\u306F\u3001\n\u305D\u308C\u3089\u306E\u30E2\u30B8\u30E5\u30FC\u30EB\u306E\u3059\u3079\u3066\u306E\"requires transitive\"\u4F9D\u5B58\u6027\u3092\u8FFD\u52A0\u3067\n\u542B\u3081\u307E\u3059\u3002\"all\"\u306E\u5024\u306F\u3001\u305D\u308C\u3089\u306E\u30E2\u30B8\u30E5\u30FC\u30EB\u306E\u3059\u3079\u3066\u306E\u4F9D\u5B58\u6027\u3092\n\u542B\u3081\u307E\u3059\u3002" },
            { "main.opt.extdirs.arg", "<dirlist>" },
            { "main.opt.extdirs.desc", "\u30A4\u30F3\u30B9\u30C8\u30FC\u30EB\u6E08\u307F\u62E1\u5F35\u6A5F\u80FD\u306E\u4F4D\u7F6E\u3092\u30AA\u30FC\u30D0\u30FC\u30E9\u30A4\u30C9\u3059\u308B" },
            { "main.opt.help.desc", "\u30B3\u30DE\u30F3\u30C9\u30E9\u30A4\u30F3\u30FB\u30AA\u30D7\u30B7\u30E7\u30F3\u3092\u8868\u793A\u3057\u3066\u7D42\u4E86\u3059\u308B" },
            { "main.opt.help.extra.desc", "\u975E\u6A19\u6E96\u30AA\u30D7\u30B7\u30E7\u30F3\u306E\u6982\u8981\u3092\u51FA\u529B\u3057\u7D42\u4E86\u3059\u308B" },
            { "main.opt.limit.modules.arg", "<module>(,<module>)*" },
            { "main.opt.limit.modules.desc", "\u53C2\u7167\u53EF\u80FD\u306A\u30E2\u30B8\u30E5\u30FC\u30EB\u306E\u9818\u57DF\u3092\u5236\u9650\u3057\u307E\u3059" },
            { "main.opt.locale.arg", "<name>" },
            { "main.opt.locale.desc", "en_US\u3084en_US_WIN\u306A\u3069\u306E\u4F7F\u7528\u3059\u308B\u30ED\u30B1\u30FC\u30EB" },
            { "main.opt.module.arg", "<module>(,<module>)*" },
            { "main.opt.module.desc", "\u6307\u5B9A\u3055\u308C\u305F\u30E2\u30B8\u30E5\u30FC\u30EB\u3092\u30C9\u30AD\u30E5\u30E1\u30F3\u30C8\u5316\u3059\u308B" },
            { "main.opt.module.path.arg", "<path>" },
            { "main.opt.module.path.desc", "\u30A2\u30D7\u30EA\u30B1\u30FC\u30B7\u30E7\u30F3\u30FB\u30E2\u30B8\u30E5\u30FC\u30EB\u3092\u691C\u7D22\u3059\u308B\u4F4D\u7F6E\u3092\u6307\u5B9A\u3059\u308B" },
            { "main.opt.module.source.path.arg", "<path>" },
            { "main.opt.module.source.path.desc", "\u8907\u6570\u30E2\u30B8\u30E5\u30FC\u30EB\u306E\u5165\u529B\u30BD\u30FC\u30B9\u30FB\u30D5\u30A1\u30A4\u30EB\u3092\u691C\u7D22\u3059\u308B\u4F4D\u7F6E\u3092\u6307\u5B9A\u3059\u308B" },
            { "main.opt.package.desc", "package/protected/public\u30BF\u30A4\u30D7\u3068\u30E1\u30F3\u30D0\u30FC\u3092\u8868\u793A\u3057\u307E\u3059\u3002\u540D\u524D\u306E\u3042\u308B\n\u30E2\u30B8\u30E5\u30FC\u30EB\u306E\u5834\u5408\u3001\u3059\u3079\u3066\u306E\u30D1\u30C3\u30B1\u30FC\u30B8\u3068\u3059\u3079\u3066\u306E\u30E2\u30B8\u30E5\u30FC\u30EB\u8A73\u7D30\u3092\u8868\u793A\u3057\u307E\u3059\u3002" },
            { "main.opt.patch.module.arg", "<module>=<file>(:<file>)*" },
            { "main.opt.patch.module.desc", "JAR\u30D5\u30A1\u30A4\u30EB\u307E\u305F\u306F\u30C7\u30A3\u30EC\u30AF\u30C8\u30EA\u306E\u30AF\u30E9\u30B9\u304A\u3088\u3073\u30EA\u30BD\u30FC\u30B9\u3067\u30E2\u30B8\u30E5\u30FC\u30EB\u3092\n        \u30AA\u30FC\u30D0\u30FC\u30E9\u30A4\u30C9\u307E\u305F\u306F\u62E1\u5F35\u3057\u307E\u3059" },
            { "main.opt.private.desc", "\u3059\u3079\u3066\u306E\u30BF\u30A4\u30D7\u3068\u30E1\u30F3\u30D0\u30FC\u3092\u8868\u793A\u3057\u307E\u3059\u3002\u540D\u524D\u306E\u3042\u308B\u30E2\u30B8\u30E5\u30FC\u30EB\u306E\u5834\u5408\u3001\n\u3059\u3079\u3066\u306E\u30D1\u30C3\u30B1\u30FC\u30B8\u3068\u3059\u3079\u3066\u306E\u30E2\u30B8\u30E5\u30FC\u30EB\u8A73\u7D30\u3092\u8868\u793A\u3057\u307E\u3059\u3002" },
            { "main.opt.protected.desc", "protected/public\u30BF\u30A4\u30D7\u3068\u30E1\u30F3\u30D0\u30FC(\u30C7\u30D5\u30A9\u30EB\u30C8)\u3092\u8868\u793A\u3057\u307E\u3059\u3002\u540D\u524D\u306E\u3042\u308B\n\u30E2\u30B8\u30E5\u30FC\u30EB\u306E\u5834\u5408\u3001\u30A8\u30AF\u30B9\u30DD\u30FC\u30C8\u3055\u308C\u305F\u30D1\u30C3\u30B1\u30FC\u30B8\u3068\u30E2\u30B8\u30E5\u30FC\u30EB\u306EAPI\u3092\u8868\u793A\u3057\u307E\u3059\u3002" },
            { "main.opt.public.desc", "public\u30BF\u30A4\u30D7\u3068\u30E1\u30F3\u30D0\u30FC\u306E\u307F\u3092\u8868\u793A\u3057\u307E\u3059\u3002\u540D\u524D\u306E\u3042\u308B\u30E2\u30B8\u30E5\u30FC\u30EB\u306E\u5834\u5408\u3001\n\u30A8\u30AF\u30B9\u30DD\u30FC\u30C8\u3055\u308C\u305F\u30D1\u30C3\u30B1\u30FC\u30B8\u3068\u30E2\u30B8\u30E5\u30FC\u30EB\u306EAPI\u3092\u8868\u793A\u3057\u307E\u3059\u3002" },
            { "main.opt.quiet.desc", "\u72B6\u614B\u30E1\u30C3\u30BB\u30FC\u30B8\u3092\u8868\u793A\u3057\u306A\u3044" },
            { "main.opt.release.arg", "<release>" },
            { "main.opt.release.desc", "\u6307\u5B9A\u3055\u308C\u305F\u30EA\u30EA\u30FC\u30B9\u3068\u30BD\u30FC\u30B9\u306E\u4E92\u63DB\u6027\u3092\u4FDD\u3064" },
            { "main.opt.show.members.arg", "<value>" },
            { "main.opt.show.members.desc", "\u5024\u304C\"public\"\u3001\"protected\"\u3001\"package\"\u307E\u305F\u306F\"private\"\u306E\u3044\u305A\u308C\u304B\u306E\n\u3069\u306E\u30E1\u30F3\u30D0\u30FC(\u30D5\u30A3\u30FC\u30EB\u30C9\u3084\u30E1\u30BD\u30C3\u30C9\u306A\u3069)\u3092\u30C9\u30AD\u30E5\u30E1\u30F3\u30C8\u5316\u3059\u308B\u304B\u3092\u6307\u5B9A\u3059\u308B\u3002\n\u30C7\u30D5\u30A9\u30EB\u30C8\u306F\"protected\"\u3067\u3001public\u304A\u3088\u3073protected\u30E1\u30F3\u30D0\u30FC\u304C\u8868\u793A\u3055\u308C\u3001\n\"public\"\u3067\u306Fpublic\u30E1\u30F3\u30D0\u30FC\u306E\u307F\u304C\u8868\u793A\u3055\u308C\u307E\u3059\u3002\"package\"\u3067\u306F\npublic\u3001protected\u304A\u3088\u3073package\u30E1\u30F3\u30D0\u30FC\u304C\u8868\u793A\u3055\u308C\u3001\"private\"\n\u3067\u306F\u3059\u3079\u3066\u306E\u30E1\u30F3\u30D0\u30FC\u304C\u8868\u793A\u3055\u308C\u307E\u3059\u3002" },
            { "main.opt.show.module.contents.arg", "<value>" },
            { "main.opt.show.module.contents.desc", "\u30E2\u30B8\u30E5\u30FC\u30EB\u5BA3\u8A00\u306E\u30C9\u30AD\u30E5\u30E1\u30F3\u30C8\u5316\u306E\u7C92\u5EA6\u3092\u6307\u5B9A\u3059\u308B\u3002\n\u4F7F\u7528\u53EF\u80FD\u306A\u5024\u306F\u3001\"api\"\u307E\u305F\u306F\"all\"\u3067\u3059\u3002" },
            { "main.opt.show.packages.arg", "<value>" },
            { "main.opt.show.packages.desc", "\u3069\u306E\u30E2\u30B8\u30E5\u30FC\u30EB\u306E\u30D1\u30C3\u30B1\u30FC\u30B8\u3092\u30C9\u30AD\u30E5\u30E1\u30F3\u30C8\u5316\u3059\u308B\u304B\u3092\u6307\u5B9A\u3059\u308B\u3002\u4F7F\u7528\u53EF\u80FD\u306A\n\u5024\u306F\u3001\"exported\"\u307E\u305F\u306F\"all\"\u30D1\u30C3\u30B1\u30FC\u30B8\u3067\u3059\u3002" },
            { "main.opt.show.types.arg", "<value>" },
            { "main.opt.show.types.desc", "\u5024\u304C\"public\"\u3001\"protected\"\u3001\"package\"\u307E\u305F\u306F\"private\"\u306E\u3044\u305A\u308C\u304B\u306E\n\u3069\u306E\u578B(\u30AF\u30E9\u30B9\u3084\u30A4\u30F3\u30BF\u30D5\u30A7\u30FC\u30B9\u306A\u3069)\u3092\u30C9\u30AD\u30E5\u30E1\u30F3\u30C8\u5316\u3059\u308B\u304B\u3092\u6307\u5B9A\u3059\u308B\u3002\n\u30C7\u30D5\u30A9\u30EB\u30C8\u306F\"protected\"\u3067\u3001public\u304A\u3088\u3073protected\u578B\u304C\u8868\u793A\u3055\u308C\u3001\n\"public\"\u3067\u306Fpublic\u578B\u306E\u307F\u304C\u8868\u793A\u3055\u308C\u307E\u3059\u3002\"package\"\u3067\u306F\npublic\u3001protected\u304A\u3088\u3073package\u578B\u304C\u8868\u793A\u3055\u308C\u3001\"private\"\n\u3067\u306F\u3059\u3079\u3066\u306E\u578B\u304C\u8868\u793A\u3055\u308C\u307E\u3059\u3002" },
            { "main.opt.source.arg", "<release>" },
            { "main.opt.source.desc", "\u6307\u5B9A\u3055\u308C\u305F\u30EA\u30EA\u30FC\u30B9\u3068\u30BD\u30FC\u30B9\u306E\u4E92\u63DB\u6027\u3092\u4FDD\u3064" },
            { "main.opt.source.path.arg", "<path>" },
            { "main.opt.source.path.desc", "\u30BD\u30FC\u30B9\u30FB\u30D5\u30A1\u30A4\u30EB\u306E\u3042\u308B\u5834\u6240\u3092\u6307\u5B9A\u3059\u308B" },
            { "main.opt.subpackages.arg", "<subpkglist>" },
            { "main.opt.subpackages.desc", "\u518D\u5E30\u7684\u306B\u30ED\u30FC\u30C9\u3059\u308B\u30B5\u30D6\u30D1\u30C3\u30B1\u30FC\u30B8\u3092\u6307\u5B9A\u3059\u308B" },
            { "main.opt.system.arg", "<jdk>" },
            { "main.opt.system.desc", "\u30E2\u30B8\u30E5\u30E9\u30FB\u30EA\u30EA\u30FC\u30B9\u3067\u4F7F\u7528\u3055\u308C\u308B\u30B7\u30B9\u30C6\u30E0\u30FB\u30E2\u30B8\u30E5\u30FC\u30EB\u306E\u5834\u6240\u3092\u30AA\u30FC\u30D0\u30FC\u30E9\u30A4\u30C9\u3059\u308B" },
            { "main.opt.upgrade.module.path.arg", "<path>" },
            { "main.opt.upgrade.module.path.desc", "\u30A2\u30C3\u30D7\u30B0\u30EC\u30FC\u30C9\u53EF\u80FD\u306A\u30E2\u30B8\u30E5\u30FC\u30EB\u306E\u4F4D\u7F6E\u3092\u30AA\u30FC\u30D0\u30FC\u30E9\u30A4\u30C9\u3059\u308B" },
            { "main.opt.verbose.desc", "Javadoc\u306E\u52D5\u4F5C\u306B\u3064\u3044\u3066\u30E1\u30C3\u30BB\u30FC\u30B8\u3092\u51FA\u529B\u3059\u308B" },
            { "main.opt.version.desc", "\u30D0\u30FC\u30B8\u30E7\u30F3\u60C5\u5831\u3092\u51FA\u529B\u3059\u308B" },
            { "main.out.of.memory", "java.lang.OutOfMemoryError: \u30E1\u30E2\u30EA\u30FC\u3092\u5897\u3084\u3057\u3066\u304F\u3060\u3055\u3044\u3002\n\u305F\u3068\u3048\u3070\u3001JDK\u306Eclassic\u3082\u3057\u304F\u306Fhotspot VM\u3067\u306F\u3001-J-Xmx32m\u306E\u3088\u3046\u306B\n-J-Xmx\u30AA\u30D7\u30B7\u30E7\u30F3\u3092\u4F7F\u7528\u3057\u307E\u3059\u3002" },
            { "main.package_not_found", "\u30D1\u30C3\u30B1\u30FC\u30B8{0}\u304C\u898B\u3064\u304B\u308A\u307E\u305B\u3093\u3067\u3057\u305F" },
            { "main.requires_argument", "\u30AA\u30D7\u30B7\u30E7\u30F3{0}\u306B\u306F\u5F15\u6570\u304C\u5FC5\u8981\u3067\u3059\u3002" },
            { "main.sourcepath_does_not_contain_module", "\u30BD\u30FC\u30B9\u30FB\u30D1\u30B9\u306B\u30E2\u30B8\u30E5\u30FC\u30EB{0}\u304C\u542B\u307E\u308C\u3066\u3044\u307E\u305B\u3093" },
            { "main.unexpected.exception", "\u4E88\u671F\u3057\u306A\u3044\u4F8B\u5916\u304C\u6355\u6349\u3055\u308C\u307E\u3057\u305F: {0}" },
            { "main.unknown.error", "\u4E0D\u660E\u306A\u30A8\u30E9\u30FC\u304C\u767A\u751F\u3057\u307E\u3057\u305F" },
            { "main.unnecessary_arg_provided", "\u30AA\u30D7\u30B7\u30E7\u30F3{0}\u306F\u5F15\u6570\u3092\u5FC5\u8981\u3068\u3057\u307E\u305B\u3093" },
            { "main.usage", "\u4F7F\u7528\u65B9\u6CD5:\n    javadoc [options] [packagenames] [sourcefiles] [@files]\n\u30AA\u30D7\u30B7\u30E7\u30F3\u306F\u6B21\u306E\u3068\u304A\u308A\u3067\u3059:" },
            { "main.usage.foot", "\nGNU\u30B9\u30BF\u30A4\u30EB\u30FB\u30AA\u30D7\u30B7\u30E7\u30F3\u3067\u306F\u3001\u30AA\u30D7\u30B7\u30E7\u30F3\u306E\u540D\u524D\u3068\u305D\u306E\u5024\u3092\u533A\u5207\u308B\u305F\u3081\u306B\u7A7A\u767D\u3067\u306F\u306A\u304F'='\u3092\n\u4F7F\u7528\u3067\u304D\u307E\u3059\u3002\n" },
            { "main.warning", "\u8B66\u544A{0}\u500B" },
            { "main.warnings", "\u8B66\u544A{0}\u500B" },
        };
    }
}
